# Scope

This is the scope description.

There may be mutliple paragraphs.

Or even a list:

- wun
- two
- three

## Scope Subsection

Sometimes authors even insert subsections into the scope.

## Glossary

Term
:    Words with special meaning

Design_Term
:    Terms with meaning different from similar words in the natural language.
